#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_COT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_COT_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/scalar/cot.hpp>

#endif
